pub fn key_rotation_sign_bytes(stmt: &KeyRotationStatement) -> Vec<u8> ⓘExpand description
Canonical bytes signed by both old and new keys in KeyRotationStatement. Keys: new_id, new_pub_key, old_id, old_pub_key, reason, rotated_at, version.
pub fn key_rotation_sign_bytes(stmt: &KeyRotationStatement) -> Vec<u8> ⓘCanonical bytes signed by both old and new keys in KeyRotationStatement. Keys: new_id, new_pub_key, old_id, old_pub_key, reason, rotated_at, version.